@@ -1,6 +1,6 @@
 import logging
 from tricc_oo.converters.utils import clean_name, clean_str
-from tricc_oo.models.tricc import TriccNodeSelectOption, TRICC_TRUE_VALUE, TRICC_FALSE_VALUE
+from tricc_oo.models.tricc import TriccNodeSelectOption, TRICC_TRUE_VALUE, TRICC_FALSE_VALUE, TriccNodeActivity
 from tricc_oo.models.calculate import TriccNodeInput
 from tricc_oo.models.base import TriccNodeBaseModel, TriccStatic, TriccReference
 
@@ -43,6 +43,8 @@ def get_export_name(node, replace_dots=True):
             value = node.name
         elif isinstance(node, TriccStatic):
             value = node.value
+            if isinstance(value, TriccNodeSelectOption):
+                value = value.name
         else:
             value = node
         if isinstance(value, bool):  # or r.value in ('true', 'false')
@@ -64,8 +66,14 @@ def get_export_name(node, replace_dots=True):
         return node
     else:
         node.gen_name()
-        if isinstance(node, TriccNodeSelectOption):
+        if isinstance(node, TriccNodeActivity) and getattr(node, 'instance', 1)>1:
+            node.export_name = clean_name(
+                node.name + INSTANCE_SEPARATOR + str(node.instance),
+                replace_dots=replace_dots,
+            )
+        elif isinstance(node, TriccNodeSelectOption):
             node.export_name = node.name
+            
         elif node.last is False:
             node.export_name = clean_name(
                 node.name + VERSION_SEPARATOR + str(node.version),
