@@ -11,7 +11,7 @@ from tricc_oo.models.ordered_set import OrderedSet
 
 logger = logging.getLogger("default")
 
-Expression = Annotated[str, StringConstraints(pattern=r"^[^\\/\:]+$")]
+Expression = Annotated[str, StringConstraints(pattern=r".+")]
 
 triccId = Annotated[str, StringConstraints(pattern=r"^[^\\/\: ]+$")]
 
@@ -274,7 +274,7 @@ class TriccNodeBaseModel(TriccBaseModel):
 
 
 class TriccStatic(BaseModel):
-    value: Union[str, float, int, bool]
+    value: Union[str, float, int, bool, TriccNodeBaseModel]
 
     def __init__(self, value):
         super().__init__(value=value)
