@@ -6,13 +6,14 @@ from tricc_oo.converters.tricc_to_xls_form import (
     get_export_name, BOOLEAN_MAP
 )
 from tricc_oo.models.lang import SingletonLangClass
-from tricc_oo.converters.utils import clean_name, remove_html
+from tricc_oo.converters.utils import clean_name, remove_html, generate_id
 from tricc_oo.models.base import (
     TriccOperator,
     TriccOperation, TriccStatic, TriccReference, and_join, TriccNodeType
 )
 from tricc_oo.models.calculate import (
     TriccNodeDisplayCalculateBase,
+    TriccNodeCalculate
 )
 from tricc_oo.models.tricc import (
     TriccNodeActivity, TriccNodeBaseModel, TriccNodeSelectMultiple, TriccNodeSelectOption,
@@ -38,6 +39,7 @@ logger = logging.getLogger("default")
 langs = SingletonLangClass()
 TRICC_CALC_EXPRESSION = "${{{0}}}>0"
 
+def get_export_group_name(in_node):return f"gcalc_{get_export_name(in_node)}"
 
 def start_group(
     strategy,
@@ -60,24 +62,38 @@ def start_group(
         groups[name] = 0
     is_activity = isinstance(cur_group, TriccNodeActivity)
     relevance = relevance and cur_group.relevance is not None and cur_group.relevance != ""
-
-    group_calc_required = False and relevance and not is_activity and len(relevance) > 100
-
+    past_instances = len(getattr(cur_group.base_instance, "instances", []))
+    group_calc_required = relevance is not None and (len(str(relevance)) > 100 or past_instances>1)
+    calc = None
+    if group_calc_required and getattr(cur_group.relevance, 'operator', None) != TriccOperator.ISTRUE:
+        
+        calc = TriccNodeCalculate(
+            id=generate_id(get_export_group_name(name)),
+            group=cur_group,
+            activity=cur_group.activity,
+            name=get_export_group_name(name),
+            expression=cur_group.relevance
+        )
+        if calc not in cur_group.calculates:
+            cur_group.calculates.append(calc)
+            processed_nodes.add(calc)
+            
+        cur_group.relevance = TriccOperation(
+                TriccOperator.ISTRUE,
+                [calc]
+            )
+    
     relevance_expression = cur_group.relevance
     relevance_expression = get_applicability_expression(cur_group, processed_nodes, process, relevance_expression)
     relevance_expression = get_prev_instance_skip_expression(cur_group, processed_nodes, process, relevance_expression)
     relevance_expression = get_process_skip_expression(cur_group, processed_nodes, process, relevance_expression)
 
+
     if not relevance:
-        relevance_expression = ""
+        relevance_expression_str = ""
     elif isinstance(relevance_expression, (TriccOperation, TriccStatic)):
-        relevance_expression = strategy.get_tricc_operation_expression(relevance_expression)
-
-    # elif is_activity:
-    #    relevance_expression = TRICC_CALC_EXPRESSION.format(get_export_name(cur_group.root))
-    elif group_calc_required:
-        relevance_expression = TRICC_CALC_EXPRESSION.format("gcalc_" + name)
-
+        relevance_expression_str = strategy.get_tricc_operation_expression(relevance_expression)
+    
     # group
     values = []
     for column in SURVEY_MAP:
@@ -91,23 +107,23 @@ def start_group(
             if relevance_expression is True:
                 values.append("")
             else:
-                values.append(relevance_expression)
+                values.append(relevance_expression_str)
 
         else:
             values.append(get_xfrom_trad(strategy, cur_group, column, SURVEY_MAP))
     df_survey.loc[len(df_survey)] = values
 
     # calc
-    if group_calc_required and len(df_calculate[df_calculate["name"] == "gcalc_" + name]) == 0:
+    if calc and len(df_calculate[df_calculate["name"] ==  get_export_group_name(name)]) == 0:
         calc_values = []
         for column in SURVEY_MAP:
             if column == "type":
                 calc_values.append("calculate")
             elif column == "name":
-                value = "gcalc_" + name
+                value = get_export_name(calc)
                 calc_values.append(value)
             elif column == "calculation":
-                calc_values.append(get_attr_if_exists(strategy, cur_group, "relevance", SURVEY_MAP))
+                calc_values.append(f"number({strategy.get_tricc_operation_expression(calc.expression)}")
             elif column == "relevance":
                 calc_values.append("")
             else:
@@ -399,7 +415,7 @@ def get_more_info_select(strategy, node):
         if column == "type":
             values.append("select_one more_info")
         elif column == "label":
-            values.append("NO_LABEL")
+            values.append(strategy.get_empty_label())
         elif column == "name":
             values.append(get_export_name(node) + "_optin")
         elif column == "hint":
